@@ -1,6 +1,6 @@
-__all__ = ['client', 'user_auth', 'aws_auth']
+__all__ = ['client', 'user_auth', 'aws_auth', 'util']
 
-CLIENT_VERSION = '0.8.0'
+CLIENT_VERSION = '1.1.0'
 
 
 class CerberusClientException(Exception):
